netapp_ontap.resources.nvme_subsystem_controller API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.nvme_subsystem_controller`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Overview

Non-Volatile Memory Express (NVMe) subsystem controllers represent dynamic connections between hosts and a storage solution.
The NVMe subsystem controllers REST API provides information about connected hosts.

## Examples

### Retrieving the NVMe subsystem controllers for the entire system

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NvmeSubsystemController

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(NvmeSubsystemController.get_collection()))

Try it out

    [
        NvmeSubsystemController(
            {
                "_links": {
                    "self": {
                        "href": "/api/protocols/nvme/subsystem-controllers/14875240-2594-11e9-abde-00a098984313/0040h"
                    }
                },
                "id": "0040h",
                "subsystem": {
                    "_links": {
                        "self": {
                            "href": "/api/protocols/nvme/subsystems/14875240-2594-11e9-abde-00a098984313"
                        }
                    },
                    "name": "symmcon_symmcon_fcnvme_vserver_0_subsystem_0",
                    "uuid": "14875240-2594-11e9-abde-00a098984313",
                },
                "svm": {
                    "name": "symmcon_fcnvme_vserver_0",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/f0f5b928-2593-11e9-94c4-00a0989a1c8e"
                        }
                    },
                    "uuid": "f0f5b928-2593-11e9-94c4-00a0989a1c8e",
                },
            }
        ),
        NvmeSubsystemController(
            {
                "_links": {
                    "self": {
                        "href": "/api/protocols/nvme/subsystem-controllers/14875240-2594-11e9-abde-00a098984313/0041h"
                    }
                },
                "id": "0041h",
                "subsystem": {
                    "_links": {
                        "self": {
                            "href": "/api/protocols/nvme/subsystems/14875240-2594-11e9-abde-00a098984313"
                        }
                    },
                    "name": "symmcon_symmcon_fcnvme_vserver_0_subsystem_0",
                    "uuid": "14875240-2594-11e9-abde-00a098984313",
                },
                "svm": {
                    "name": "symmcon_fcnvme_vserver_0",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/f0f5b928-2593-11e9-94c4-00a0989a1c8e"
                        }
                    },
                    "uuid": "f0f5b928-2593-11e9-94c4-00a0989a1c8e",
                },
            }
        ),
        NvmeSubsystemController(
            {
                "_links": {
                    "self": {
                        "href": "/api/protocols/nvme/subsystem-controllers/1489d0d5-2594-11e9-94c4-00a0989a1c8e/0040h"
                    }
                },
                "id": "0040h",
                "subsystem": {
                    "_links": {
                        "self": {
                            "href": "/api/protocols/nvme/subsystems/1489d0d5-2594-11e9-94c4-00a0989a1c8e"
                        }
                    },
                    "name": "symmcon_symmcon_fcnvme_vserver_0_subsystem_1",
                    "uuid": "1489d0d5-2594-11e9-94c4-00a0989a1c8e",
                },
                "svm": {
                    "name": "symmcon_fcnvme_vserver_0",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/f0f5b928-2593-11e9-94c4-00a0989a1c8e"
                        }
                    },
                    "uuid": "f0f5b928-2593-11e9-94c4-00a0989a1c8e",
                },
            }
        ),
        NvmeSubsystemController(
            {
                "_links": {
                    "self": {
                        "href": "/api/protocols/nvme/subsystem-controllers/1489d0d5-2594-11e9-94c4-00a0989a1c8e/0041h"
                    }
                },
                "id": "0041h",
                "subsystem": {
                    "_links": {
                        "self": {
                            "href": "/api/protocols/nvme/subsystems/1489d0d5-2594-11e9-94c4-00a0989a1c8e"
                        }
                    },
                    "name": "symmcon_symmcon_fcnvme_vserver_0_subsystem_1",
                    "uuid": "1489d0d5-2594-11e9-94c4-00a0989a1c8e",
                },
                "svm": {
                    "name": "symmcon_fcnvme_vserver_0",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/f0f5b928-2593-11e9-94c4-00a0989a1c8e"
                        }
                    },
                    "uuid": "f0f5b928-2593-11e9-94c4-00a0989a1c8e",
                },
            }
        ),
    ]

### Retrieving the NVMe subsystem controllers for a specific subsystem

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NvmeSubsystemController

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(
            list(
                NvmeSubsystemController.get_collection(
                    **{"subsystem.uuid": "14875240-2594-11e9-abde-00a098984313"}
                )
            )
        )

Try it out

    [
        NvmeSubsystemController(
            {
                "_links": {
                    "self": {
                        "href": "/api/protocols/nvme/subsystem-controllers/14875240-2594-11e9-abde-00a098984313/0040h"
                    }
                },
                "id": "0040h",
                "subsystem": {
                    "_links": {
                        "self": {
                            "href": "/api/protocols/nvme/subsystems/14875240-2594-11e9-abde-00a098984313"
                        }
                    },
                    "name": "symmcon_symmcon_fcnvme_vserver_0_subsystem_0",
                    "uuid": "14875240-2594-11e9-abde-00a098984313",
                },
                "svm": {
                    "name": "symmcon_fcnvme_vserver_0",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/f0f5b928-2593-11e9-94c4-00a0989a1c8e"
                        }
                    },
                    "uuid": "f0f5b928-2593-11e9-94c4-00a0989a1c8e",
                },
            }
        ),
        NvmeSubsystemController(
            {
                "_links": {
                    "self": {
                        "href": "/api/protocols/nvme/subsystem-controllers/14875240-2594-11e9-abde-00a098984313/0041h"
                    }
                },
                "id": "0041h",
                "subsystem": {
                    "_links": {
                        "self": {
                            "href": "/api/protocols/nvme/subsystems/14875240-2594-11e9-abde-00a098984313"
                        }
                    },
                    "name": "symmcon_symmcon_fcnvme_vserver_0_subsystem_0",
                    "uuid": "14875240-2594-11e9-abde-00a098984313",
                },
                "svm": {
                    "name": "symmcon_fcnvme_vserver_0",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/f0f5b928-2593-11e9-94c4-00a0989a1c8e"
                        }
                    },
                    "uuid": "f0f5b928-2593-11e9-94c4-00a0989a1c8e",
                },
            }
        ),
    ]

### Retrieving a specific NVMe subsystem controller

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NvmeSubsystemController

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = NvmeSubsystemController(
            id="0040h", **{"subsystem.uuid": "14875240-2594-11e9-abde-00a098984313"}
        )
        resource.get()
        print(resource)

Try it out

    NvmeSubsystemController(
        {
            "admin_queue": {"depth": 32},
            "_links": {
                "self": {
                    "href": "/api/protocols/nvme/subsystem-controllers/14875240-2594-11e9-abde-00a098984313/0040h"
                }
            },
            "host": {
                "nqn": "nqn.2014-08.org.nvmexpress:uuid:c2846cb1-89d2-4020-a3b0-71ce907b4eef",
                "id": "b8546ca6097349e5b1558dc154fc073b",
                "transport_address": "nn-0x20000090fae00806:pn-0x10000090fae00806",
            },
            "dh_hmac_chap": {"mode": "none"},
            "interface": {
                "name": "symmcon_lif_fcnvme_symmcon_fcnvme_vserver_0_3a_0",
                "transport_address": "nn-0x200400a0989a1c8d:pn-0x200500a0989a1c8d",
                "uuid": "fa1c5941-2593-11e9-94c4-00a0989a1c8e",
            },
            "io_queue": {"depth": [32, 32, 32, 32], "count": 4},
            "id": "0040h",
            "digest": {"data": False, "header": True},
            "subsystem": {
                "_links": {
                    "self": {
                        "href": "/api/protocols/nvme/subsystems/14875240-2594-11e9-abde-00a098984313"
                    }
                },
                "name": "symmcon_symmcon_fcnvme_vserver_0_subsystem_0",
                "uuid": "14875240-2594-11e9-abde-00a098984313",
            },
            "keep_alive_timeout": 4000,
            "node": {
                "name": "ssan-8040-94a",
                "_links": {
                    "self": {
                        "href": "/api/cluster/nodes/ebf66f05-2590-11e9-abde-00a098984313"
                    }
                },
                "uuid": "ebf66f05-2590-11e9-abde-00a098984313",
            },
            "tls": {
                "cipher": "tls_aes_128_gcm_sha256",
                "psk_identity": "NVMe1R01 nqn.2014-08.org.nvmexpress:uuid:c2846cb1-89d2-4020-a3b0-71ce907b4eef nqn.1992-08.com.netapp:sn.ca3cae02070811ef9a53005056bb9001:subsystem.ss1 c9X3RurQxGiGa76Tpk2tirifrUhHmVp035MOrtHXnAU=",
                "key_type": "configured",
            },
            "svm": {
                "name": "symmcon_fcnvme_vserver_0",
                "_links": {
                    "self": {"href": "/api/svm/svms/f0f5b928-2593-11e9-94c4-00a0989a1c8e"}
                },
                "uuid": "f0f5b928-2593-11e9-94c4-00a0989a1c8e",
            },
        }
    )

## Classes

`class NvmeSubsystemController (*args, **kwargs)`

  A Non-Volatile Memory Express (NVMe) subsystem controller represents a connection between a host and a storage solution.
  An NVMe subsystem controller is identified by the NVMe subsystem UUID and the controller ID.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection (*args, connection: HostConnection = None, **kwargs) -> int`

    Returns a count of all NvmeSubsystemController resources that match the provided query

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def fast_get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[RawResource]`

    Returns a list of RawResources that represent NvmeSubsystemController resources that match the provided query

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def find (*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves NVMe subsystem controllers.

    ### Related ONTAP commands

    - `vserver nvme subsystem controller show`

    ### Learn more

    - `DOC /protocols/nvme/subsystem-controllers`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[Resource]`

    Retrieves NVMe subsystem controllers.

    ### Related ONTAP commands

    - `vserver nvme subsystem controller show`

    ### Learn more

    - `DOC /protocols/nvme/subsystem-controllers`

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  ### Methods

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves an NVMe subsystem controller.

    ### Related ONTAP commands

    - `vserver nvme subsystem controller show`

    ### Learn more

    - `DOC /protocols/nvme/subsystem-controllers`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class NvmeSubsystemControllerSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the NvmeSubsystemController object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `admin_queue: NvmeSubsystemControllerAdminQueue GET`

    The admin_queue field of the nvme_subsystem_controller.

  `dh_hmac_chap: NvmeSubsystemControllerDhHmacChap GET`

    A container for properties of the NVMe in-band authentication DH-HMAC-CHAP protocol used by the the host connection to the controller.

  `digest: NvmeSubsystemControllerDigest GET`

    Digests are properties of NVMe controllers created over the NVMe/TCP transport protocol. The usage of digests is negotiated between the host and the controller during connection setup. ONTAP enables digests only if the host requests them. The header digest is the crc32 checksum of the header portion of the NVMe/TCP PDU. The data digest is the crc32 checksum of the data portion of the NVMe/TCP PDU.
    If a digest is enabled, upon receiving an NVMe/TCP PDU, ONTAP calculates the crc32 checksum of the associated portion of the PDU and compares it with the digest value present in the transmitted PDU. If there is a mismatch, ONTAP returns an error and destroys the controller.

  `host: NvmeSubsystemControllerHost GET`

    Properties of the connected host.

  `id: str GET`

    The identifier of the subsystem controller. This field consists of 4 zero-filled hexadecimal digits followed by an 'h'.

    Example: 0040h

  `interface: NvmeSubsystemControllerInterface GET`

    The logical interface through which the host is connected.

  `io_queue: NvmeSubsystemControllerIoQueue GET`

    Properties of the I/O queues available to the controller.

  `keep_alive_timeout: Size GET`

    The keep-alive timeout value for the controller and all of its host connections, in milliseconds.
    If the NVMe controller does not receive a keep-alive request or an I/O request within the timeout window, the NVMe controller terminates its admin queue and I/O queue connections leading to NVMe controller teardown. If the NVMe host does not receive a response to a keep-alive request or an I/O request within the timeout window, the NVMe host initiates a connection disconnect.

    Example: 1500

  `links: SelfLink GET`

    The links field of the nvme_subsystem_controller.

  `node: Node GET`

    The node field of the nvme_subsystem_controller.

  `subsystem: NvmeSubsystem GET`

    The subsystem field of the nvme_subsystem_controller.

  `svm: Svm GET`

    The svm field of the nvme_subsystem_controller.

  `tls: NvmeSubsystemControllerTls GET`

    A container for properties that describe the encrypted NVMe/TCP transport connection between the host and the NVMe subsystem.

  `transport_protocol: str GET`

    Transport Protocol

    Valid choices:

    - fc_nvme
    - nvme_tcp
    - nvme_roce